@@ -4,17 +4,35 @@ from django.http import HttpResponseNotModified
 from django.template import Template
 from django.test import override_settings
 
-from django_components import component
+from django_components import Component, registry, types
 from django_components.middleware import ComponentDependencyMiddleware
 
-from .django_test_setup import *  # NOQA
-from .test_templatetags import SimpleComponent
-from .testutils import Django30CompatibleSimpleTestCase as SimpleTestCase
-from .testutils import create_and_process_template_response
+from .django_test_setup import setup_test_config
+from .testutils import BaseTestCase, create_and_process_template_response
+
+setup_test_config()
 
 
-class SimpleComponentAlternate(component.Component):
-    template_name = "simple_template.html"
+class SimpleComponent(Component):
+    template: types.django_html = """
+        Variable: <strong>{{ variable }}</strong>
+    """
+
+    def get_context_data(self, variable, variable2="default"):
+        return {
+            "variable": variable,
+            "variable2": variable2,
+        }
+
+    class Media:
+        css = "style.css"
+        js = "script.js"
+
+
+class SimpleComponentAlternate(Component):
+    template: types.django_html = """
+        Variable: <strong>{{ variable }}</strong>
+    """
 
     def get_context_data(self, variable):
         return {}
@@ -24,8 +42,10 @@ class SimpleComponentAlternate(component.Component):
         js = "script2.js"
 
 
-class SimpleComponentWithSharedDependency(component.Component):
-    template_name = "simple_template.html"
+class SimpleComponentWithSharedDependency(Component):
+    template: types.django_html = """
+        Variable: <strong>{{ variable }}</strong>
+    """
 
     def get_context_data(self, variable, variable2="default"):
         return {}
@@ -35,8 +55,10 @@ class SimpleComponentWithSharedDependency(component.Component):
         js = ["script.js", "script2.js"]
 
 
-class MultistyleComponent(component.Component):
-    template_name = "simple_template.html"
+class MultistyleComponent(Component):
+    template: types.django_html = """
+        Variable: <strong>{{ variable }}</strong>
+    """
 
     class Media:
         css = ["style.css", "style2.css"]
@@ -44,15 +66,14 @@ class MultistyleComponent(component.Component):
 
 
 @override_settings(COMPONENTS={"RENDER_DEPENDENCIES": True})
-class ComponentMediaRenderingTests(SimpleTestCase):
-    def setUp(self):
-        # NOTE: component.registry is global, so need to clear before each test
-        component.registry.clear()
-
+class ComponentMediaRenderingTests(BaseTestCase):
     def test_no_dependencies_when_no_components_used(self):
-        component.registry.register(name="test", component=SimpleComponent)
+        registry.register(name="test", component=SimpleComponent)
 
-        template = Template("{% load component_tags %}{% component_dependencies %}")
+        template_str: types.django_html = """
+            {% load component_tags %}{% component_dependencies %}
+        """
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertInHTML('<script src="script.js">', rendered, count=0)
         self.assertInHTML(
@@ -62,16 +83,22 @@ class ComponentMediaRenderingTests(SimpleTestCase):
         )
 
     def test_no_js_dependencies_when_no_components_used(self):
-        component.registry.register(name="test", component=SimpleComponent)
+        registry.register(name="test", component=SimpleComponent)
 
-        template = Template("{% load component_tags %}{% component_js_dependencies %}")
+        template_str: types.django_html = """
+            {% load component_tags %}{% component_js_dependencies %}
+        """
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertInHTML('<script src="script.js">', rendered, count=0)
 
     def test_no_css_dependencies_when_no_components_used(self):
-        component.registry.register(name="test", component=SimpleComponent)
+        registry.register(name="test", component=SimpleComponent)
 
-        template = Template("{% load component_tags %}{% component_css_dependencies %}")
+        template_str: types.django_html = """
+            {% load component_tags %}{% component_css_dependencies %}
+        """
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertInHTML(
             '<link href="style.css" media="all" rel="stylesheet"/>',
@@ -80,9 +107,12 @@ class ComponentMediaRenderingTests(SimpleTestCase):
         )
 
     def test_preload_dependencies_render_when_no_components_used(self):
-        component.registry.register(name="test", component=SimpleComponent)
+        registry.register(name="test", component=SimpleComponent)
 
-        template = Template("{% load component_tags %}{% component_dependencies preload='test' %}")
+        template_str: types.django_html = """
+            {% load component_tags %}{% component_dependencies preload='test' %}
+        """
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertInHTML('<script src="script.js">', rendered, count=1)
         self.assertInHTML(
@@ -92,9 +122,12 @@ class ComponentMediaRenderingTests(SimpleTestCase):
         )
 
     def test_preload_css_dependencies_render_when_no_components_used(self):
-        component.registry.register(name="test", component=SimpleComponent)
+        registry.register(name="test", component=SimpleComponent)
 
-        template = Template("{% load component_tags %}{% component_css_dependencies preload='test' %}")
+        template_str: types.django_html = """
+            {% load component_tags %}{% component_css_dependencies preload='test' %}
+        """
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertInHTML(
             '<link href="style.css" media="all" rel="stylesheet"/>',
@@ -103,12 +136,13 @@ class ComponentMediaRenderingTests(SimpleTestCase):
         )
 
     def test_single_component_dependencies_render_when_used(self):
-        component.registry.register(name="test", component=SimpleComponent)
+        registry.register(name="test", component=SimpleComponent)
 
-        template = Template(
-            "{% load component_tags %}{% component_dependencies %}"
-            "{% component 'test' variable='foo' %}{% endcomponent %}"
-        )
+        template_str: types.django_html = """
+            {% load component_tags %}{% component_dependencies %}
+            {% component 'test' variable='foo' %}{% endcomponent %}
+        """
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertInHTML(
             '<link href="style.css" media="all" rel="stylesheet"/>',
@@ -118,12 +152,13 @@ class ComponentMediaRenderingTests(SimpleTestCase):
         self.assertInHTML('<script src="script.js">', rendered, count=1)
 
     def test_single_component_with_dash_or_slash_in_name(self):
-        component.registry.register(name="test", component=SimpleComponent)
+        registry.register(name="test", component=SimpleComponent)
 
-        template = Template(
-            "{% load component_tags %}{% component_dependencies %}"
-            "{% component 'test' variable='foo' %}{% endcomponent %}"
-        )
+        template_str: types.django_html = """
+            {% load component_tags %}{% component_dependencies %}
+            {% component 'test' variable='foo' %}{% endcomponent %}
+        """
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertInHTML(
             '<link href="style.css" media="all" rel="stylesheet"/>',
@@ -133,12 +168,13 @@ class ComponentMediaRenderingTests(SimpleTestCase):
         self.assertInHTML('<script src="script.js">', rendered, count=1)
 
     def test_preload_dependencies_render_once_when_used(self):
-        component.registry.register(name="test", component=SimpleComponent)
+        registry.register(name="test", component=SimpleComponent)
 
-        template = Template(
-            "{% load component_tags %}{% component_dependencies preload='test' %}"
-            "{% component 'test' variable='foo' %}{% endcomponent %}"
-        )
+        template_str: types.django_html = """
+            {% load component_tags %}{% component_dependencies preload='test' %}
+            {% component 'test' variable='foo' %}{% endcomponent %}
+        """
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertInHTML(
             '<link href="style.css" media="all" rel="stylesheet"/>',
@@ -148,29 +184,34 @@ class ComponentMediaRenderingTests(SimpleTestCase):
         self.assertInHTML('<script src="script.js">', rendered, count=1)
 
     def test_placeholder_removed_when_single_component_rendered(self):
-        component.registry.register(name="test", component=SimpleComponent)
+        registry.register(name="test", component=SimpleComponent)
 
-        template = Template(
-            "{% load component_tags %}{% component_dependencies %}"
-            "{% component 'test' variable='foo' %}{% endcomponent %}"
-        )
+        template_str: types.django_html = """
+            {% load component_tags %}{% component_dependencies %}
+            {% component 'test' variable='foo' %}{% endcomponent %}
+        """
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertNotIn("_RENDERED", rendered)
 
     def test_placeholder_removed_when_preload_rendered(self):
-        component.registry.register(name="test", component=SimpleComponent)
+        registry.register(name="test", component=SimpleComponent)
 
-        template = Template("{% load component_tags %}{% component_dependencies preload='test' %}")
+        template_str: types.django_html = """
+            {% load component_tags %}{% component_dependencies preload='test' %}
+        """
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertNotIn("_RENDERED", rendered)
 
     def test_single_component_css_dependencies(self):
-        component.registry.register(name="test", component=SimpleComponent)
+        registry.register(name="test", component=SimpleComponent)
 
-        template = Template(
-            "{% load component_tags %}{% component_css_dependencies %}"
-            "{% component 'test' variable='foo' %}{% endcomponent %}"
-        )
+        template_str: types.django_html = """
+            {% load component_tags %}{% component_css_dependencies %}
+            {% component 'test' variable='foo' %}{% endcomponent %}
+        """
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertInHTML(
             '<link href="style.css" media="all" rel="stylesheet"/>',
@@ -179,22 +220,25 @@ class ComponentMediaRenderingTests(SimpleTestCase):
         )
 
     def test_single_component_js_dependencies(self):
-        component.registry.register(name="test", component=SimpleComponent)
+        registry.register(name="test", component=SimpleComponent)
 
-        template = Template(
-            "{% load component_tags %}{% component_js_dependencies %}"
-            "{% component 'test' variable='foo' %}{% endcomponent %}"
-        )
+        template_str: types.django_html = """
+            {% load component_tags %}{% component_js_dependencies %}
+            {% component 'test' variable='foo' %}{% endcomponent %}
+        """
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertInHTML('<script src="script.js">', rendered, count=1)
 
     def test_all_dependencies_are_rendered_for_component_with_multiple_dependencies(
         self,
     ):
-        component.registry.register(name="test", component=MultistyleComponent)
-        template = Template(
-            "{% load component_tags %}{% component_dependencies %}{% component 'test' %}{% endcomponent %}"
-        )
+        registry.register(name="test", component=MultistyleComponent)
+        template_str: types.django_html = """
+            {% load component_tags %}{% component_dependencies %}
+            {% component 'test' %}{% endcomponent %}
+        """
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertInHTML('<script src="script.js">', rendered, count=1)
         self.assertInHTML('<script src="script2.js">', rendered, count=1)
@@ -212,13 +256,12 @@ class ComponentMediaRenderingTests(SimpleTestCase):
     def test_all_js_dependencies_are_rendered_for_component_with_multiple_dependencies(
         self,
     ):
-        component.registry.register(name="test", component=MultistyleComponent)
-        template = Template(
-            """
+        registry.register(name="test", component=MultistyleComponent)
+        template_str: types.django_html = """
             {% load component_tags %}{% component_js_dependencies %}
             {% component 'test' %}{% endcomponent %}
         """
-        )
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertInHTML('<script src="script.js">', rendered, count=1)
         self.assertInHTML('<script src="script2.js">', rendered, count=1)
@@ -236,13 +279,12 @@ class ComponentMediaRenderingTests(SimpleTestCase):
     def test_all_css_dependencies_are_rendered_for_component_with_multiple_dependencies(
         self,
     ):
-        component.registry.register(name="test", component=MultistyleComponent)
-        template = Template(
-            """
+        registry.register(name="test", component=MultistyleComponent)
+        template_str: types.django_html = """
             {% load component_tags %}{% component_css_dependencies %}
             {% component 'test' %}{% endcomponent %}
         """
-        )
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertInHTML('<script src="script.js">', rendered, count=0)
         self.assertInHTML('<script src="script2.js">', rendered, count=0)
@@ -258,10 +300,13 @@ class ComponentMediaRenderingTests(SimpleTestCase):
         )
 
     def test_no_dependencies_with_multiple_unused_components(self):
-        component.registry.register(name="test1", component=SimpleComponent)
-        component.registry.register(name="test2", component=SimpleComponentAlternate)
+        registry.register(name="test1", component=SimpleComponent)
+        registry.register(name="test2", component=SimpleComponentAlternate)
 
-        template = Template("{% load component_tags %}{% component_dependencies %}")
+        template_str: types.django_html = """
+            {% load component_tags %}{% component_dependencies %}
+        """
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertInHTML('<script src="script.js">', rendered, count=0)
         self.assertInHTML('<script src="script2.js">', rendered, count=0)
@@ -277,13 +322,14 @@ class ComponentMediaRenderingTests(SimpleTestCase):
         )
 
     def test_correct_css_dependencies_with_multiple_components(self):
-        component.registry.register(name="test1", component=SimpleComponent)
-        component.registry.register(name="test2", component=SimpleComponentAlternate)
+        registry.register(name="test1", component=SimpleComponent)
+        registry.register(name="test2", component=SimpleComponentAlternate)
 
-        template = Template(
-            "{% load component_tags %}{% component_css_dependencies %}"
-            "{% component 'test1' 'variable' %}{% endcomponent %}"
-        )
+        template_str: types.django_html = """
+            {% load component_tags %}{% component_css_dependencies %}
+            {% component 'test1' 'variable' %}{% endcomponent %}
+        """
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertInHTML(
             '<link href="style.css" media="all" rel="stylesheet"/>',
@@ -297,25 +343,27 @@ class ComponentMediaRenderingTests(SimpleTestCase):
         )
 
     def test_correct_js_dependencies_with_multiple_components(self):
-        component.registry.register(name="test1", component=SimpleComponent)
-        component.registry.register(name="test2", component=SimpleComponentAlternate)
+        registry.register(name="test1", component=SimpleComponent)
+        registry.register(name="test2", component=SimpleComponentAlternate)
 
-        template = Template(
-            "{% load component_tags %}{% component_js_dependencies %}"
-            "{% component 'test1' 'variable' %}{% endcomponent %}"
-        )
+        template_str: types.django_html = """
+            {% load component_tags %}{% component_js_dependencies %}
+            {% component 'test1' 'variable' %}{% endcomponent %}
+        """
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertInHTML('<script src="script.js">', rendered, count=1)
         self.assertInHTML('<script src="script2.js">', rendered, count=0)
 
     def test_correct_dependencies_with_multiple_components(self):
-        component.registry.register(name="test1", component=SimpleComponent)
-        component.registry.register(name="test2", component=SimpleComponentAlternate)
+        registry.register(name="test1", component=SimpleComponent)
+        registry.register(name="test2", component=SimpleComponentAlternate)
 
-        template = Template(
-            "{% load component_tags %}{% component_dependencies %}"
-            "{% component 'test2' variable='variable' %}{% endcomponent %}"
-        )
+        template_str: types.django_html = """
+            {% load component_tags %}{% component_dependencies %}
+            {% component 'test2' variable='variable' %}{% endcomponent %}
+        """
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertInHTML('<script src="script.js">', rendered, count=0)
         self.assertInHTML('<script src="script2.js">', rendered, count=1)
@@ -331,18 +379,17 @@ class ComponentMediaRenderingTests(SimpleTestCase):
         )
 
     def test_shared_dependencies_rendered_once(self):
-        component.registry.register(name="test1", component=SimpleComponent)
-        component.registry.register(name="test2", component=SimpleComponentAlternate)
-        component.registry.register(name="test3", component=SimpleComponentWithSharedDependency)
+        registry.register(name="test1", component=SimpleComponent)
+        registry.register(name="test2", component=SimpleComponentAlternate)
+        registry.register(name="test3", component=SimpleComponentWithSharedDependency)
 
-        template = Template(
-            """
+        template_str: types.django_html = """
             {% load component_tags %}{% component_dependencies %}
             {% component 'test1' variable='variable' %}{% endcomponent %}
             {% component 'test2' variable='variable' %}{% endcomponent %}
             {% component 'test1' variable='variable' %}{% endcomponent %}
         """
-        )
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertInHTML('<script src="script.js">', rendered, count=1)
         self.assertInHTML('<script src="script2.js">', rendered, count=1)
@@ -358,18 +405,17 @@ class ComponentMediaRenderingTests(SimpleTestCase):
         )
 
     def test_placeholder_removed_when_multiple_component_rendered(self):
-        component.registry.register(name="test1", component=SimpleComponent)
-        component.registry.register(name="test2", component=SimpleComponentAlternate)
-        component.registry.register(name="test3", component=SimpleComponentWithSharedDependency)
+        registry.register(name="test1", component=SimpleComponent)
+        registry.register(name="test2", component=SimpleComponentAlternate)
+        registry.register(name="test3", component=SimpleComponentWithSharedDependency)
 
-        template = Template(
-            """
+        template_str: types.django_html = """
             {% load component_tags %}{% component_dependencies %}
             {% component 'test1' variable='variable' %}{% endcomponent %}
             {% component 'test2' variable='variable' %}{% endcomponent %}
             {% component 'test1' variable='variable' %}{% endcomponent %}
         """
-        )
+        template = Template(template_str)
         rendered = create_and_process_template_response(template)
         self.assertNotIn("_RENDERED", rendered)
 
@@ -388,13 +434,15 @@ class ComponentMediaRenderingTests(SimpleTestCase):
             "test_component",
         ]
         for component_name in component_names:
-            component.registry.register(name=component_name, component=SimpleComponent)
-            template = Template(
-                "{% load component_tags %}"
-                "{% component_js_dependencies %}"
-                "{% component_css_dependencies %}"
-                f"{{% component '{component_name}' variable='value' %}}{{% endcomponent %}}"
-            )
+            registry.register(name=component_name, component=SimpleComponent)
+            template_str: types.django_html = f"""
+                {{% load component_tags %}}
+                {{% component_js_dependencies %}}
+                {{% component_css_dependencies %}}
+                {{% component '{component_name}' variable='value' %}}
+                {{% endcomponent %}}
+            """
+            template = Template(template_str)
             rendered = create_and_process_template_response(template)
             self.assertHTMLEqual(
                 rendered,
